@@ -35,7 +35,7 @@ class RatedMiddleware(object):
 
         client = redis.Redis(connection_pool=POOL)
         # Do commands at once for speed
-        # We don't need these top operate in a transaction, as none of the values
+        # We don't need these to operate in a transaction, as none of the values
         # we send are dependant on values in the DB
         pipe = client.pipeline(transaction=False)
         # Add our timestamp to the range
@@ -49,6 +49,6 @@ class RatedMiddleware(object):
         size = pipe.execute()[-1]
         if size > conf.get('limit', settings.DEFAULT_LIMIT):
             return HttpResponse(conf.get('message', settings.RESPONSE_MESSAGE),
-                status=conf.get('code', settings.RESPONSE_CODE, 429)
+                status=conf.get('code', settings.RESPONSE_CODE)
             )
         return None
